diff --git a/examples/misultin_websocket_example.erl b/examples/misultin_websocket_example.erl
index c6bb113..c1f0615 100644
--- a/examples/misultin_websocket_example.erl
+++ b/examples/misultin_websocket_example.erl
@@ -28,7 +28,7 @@
 % POSSIBILITY OF SUCH DAMAGE.
 % ==========================================================================================================
 -module(misultin_websocket_example).
--export([start/1, stop/0]).
+-export([start/1, stop/0, handle_websocket/1]).
 
 % start misultin http server
 start(Port) ->
@@ -86,10 +86,11 @@ handle_websocket(Ws) ->
 	receive
 		{browser, Data} ->
 			Ws:send(["received '", Data, "'"]),
-			handle_websocket(Ws);
+			erlang:hibernate(?MODULE, handle_websocket, [Ws]);
+%			handle_websocket(Ws);
 		_Ignore ->
 			handle_websocket(Ws)
-	after 5000 ->
-		Ws:send("pushing!"),
-		handle_websocket(Ws)
+%	after 5000 ->
+%		Ws:send("pushing!"),
+%		handle_websocket(Ws)
 	end.
diff --git a/src/misultin.erl b/src/misultin.erl
index 1ec8936..22000ac 100644
--- a/src/misultin.erl
+++ b/src/misultin.erl
@@ -99,7 +99,7 @@ init([Options]) ->
 		{backlog, 128, fun is_integer/1, backlog_not_integer},
 		{acceptors_poolsize, 10, fun is_integer/1, invalid_acceptors_poolsize_option},
 		{recv_timeout, 30*1000, fun is_integer/1, recv_timeout_not_integer},
-		{max_connections, 1024, fun is_integer/1, invalid_max_connections_option},
+		{max_connections, 1048576, fun is_integer/1, invalid_max_connections_option},
 		{ssl, false, fun check_ssl_options/1, invalid_ssl_options},
 		% misultin
 		{post_max_size, 4*1012*1012, fun is_integer/1, invalid_post_max_size_option},		% defaults to 4 MB
diff --git a/src/misultin_websocket.erl b/src/misultin_websocket.erl
index de8059b..6dc63a0 100644
--- a/src/misultin_websocket.erl
+++ b/src/misultin_websocket.erl
@@ -34,7 +34,7 @@
 -vsn("0.8-dev").
 
 % API
--export([check/2, connect/4]).
+-export([check/2, connect/4, ws_loop/6]).
 
 
 % includes
@@ -229,28 +229,32 @@ ws_loop(ServerRef, Socket, Buffer, WsHandleLoopPid, SocketMode, WsAutoExit) ->
 		{send, Data} ->
 			?LOG_DEBUG("sending data to websocket: ~p", [Data]),
 			misultin_socket:send(Socket, [0, Data, 255], SocketMode),
-			ws_loop(ServerRef, Socket, Buffer, WsHandleLoopPid, SocketMode, WsAutoExit);
+			erlang:hibernate(?MODULE, ws_loop, [ServerRef, Socket, Buffer, WsHandleLoopPid, SocketMode, WsAutoExit]);
+%			ws_loop(ServerRef, Socket, Buffer, WsHandleLoopPid, SocketMode, WsAutoExit);
 		shutdown ->
 			?LOG_DEBUG("shutdown request received, closing websocket with pid ~p", [self()]),
 			% close websocket and custom controlling loop
 			websocket_close(ServerRef, Socket, WsHandleLoopPid, SocketMode, WsAutoExit);
 		_Ignored ->
 			?LOG_WARNING("received unexpected message, ignoring: ~p", [_Ignored]),
-			ws_loop(ServerRef, Socket, Buffer, WsHandleLoopPid, SocketMode, WsAutoExit)
+			erlang:hibernate(?MODULE, ws_loop, [ServerRef, Socket, Buffer, WsHandleLoopPid, SocketMode, WsAutoExit])
+%			ws_loop(ServerRef, Socket, Buffer, WsHandleLoopPid, SocketMode, WsAutoExit)
 	end.
 
 % Buffering and data handling
 handle_data(<<0, T/binary>>, none, Socket, WsHandleLoopPid, SocketMode, WsAutoExit, ServerRef) ->
 	handle_data(T, <<>>, Socket, WsHandleLoopPid, SocketMode, WsAutoExit, ServerRef);
 handle_data(<<>>, none, Socket, WsHandleLoopPid, SocketMode, WsAutoExit, ServerRef) ->
-	ws_loop(ServerRef, Socket, none, WsHandleLoopPid, SocketMode, WsAutoExit);
+	erlang:hibernate(?MODULE, ws_loop, [ServerRef, Socket, none, WsHandleLoopPid, SocketMode, WsAutoExit]);
+%	ws_loop(ServerRef, Socket, none, WsHandleLoopPid, SocketMode, WsAutoExit);
 handle_data(<<255, T/binary>>, L, Socket, WsHandleLoopPid, SocketMode, WsAutoExit, ServerRef) ->
 	WsHandleLoopPid ! {browser, binary_to_list(L)},
 	handle_data(T, none, Socket, WsHandleLoopPid, SocketMode, WsAutoExit, ServerRef);
 handle_data(<<H, T/binary>>, L, Socket, WsHandleLoopPid, SocketMode, WsAutoExit, ServerRef) ->
 	handle_data(T, <<L/binary, H>>, Socket, WsHandleLoopPid, SocketMode, WsAutoExit, ServerRef);
 handle_data(<<>>, L, Socket, WsHandleLoopPid, SocketMode, WsAutoExit, ServerRef) ->
-	ws_loop(ServerRef, Socket, L, WsHandleLoopPid, SocketMode, WsAutoExit).
+	erlang:ibernate(?MODULE, ws_loop, [ServerRef, Socket, L, WsHandleLoopPid, SocketMode, WsAutoExit]).
+%	ws_loop(ServerRef, Socket, L, WsHandleLoopPid, SocketMode, WsAutoExit).
 
 % Close socket and custom handling loop dependency
 websocket_close(ServerRef, Socket, WsHandleLoopPid, SocketMode, WsAutoExit) ->
